==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkMenuBarPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkMenuBarPeer

// class file dependencies
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class 73415100be020779 gnu_java_awt_peer_gtk_GtkMenuBarPeer
// @dep_class bf080bc730109d28 gnu_java_awt_peer_gtk_GtkMenuComponentPeer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkMenuComponentPeer

#include "gnu/java/awt/peer/gtk/GtkMenuComponentPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkMenuBarPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkMenuBarPeer_H_

// Forward structure declarations
struct _jc_java_awt_Menu$object;
struct _jc_java_awt_MenuBar$object;
struct _jc_java_awt_peer_MenuPeer$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method$_init$4781d7bab77689ff(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, struct _jc_java_awt_MenuBar$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method$addHelpMenu$817ad9a89f414626(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, struct _jc_java_awt_Menu$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method$addMenu$c531b8aa16a72c05(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, struct _jc_object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method$delMenu$26289899e46c5ca6(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, jint);
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method$nativeSetHelpMenu$5b3ac97d41e5de26(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, struct _jc_object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method$setFont$d9ef91fc08961faa(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method_info$addHelpMenu$817ad9a89f414626;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method_info$addMenu$c531b8aa16a72c05;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method_info$delMenu$26289899e46c5ca6;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method_info$nativeSetHelpMenu$5b3ac97d41e5de26;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method_info$setFont$d9ef91fc08961faa;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vmethods {
	void	(*addHelpMenu$817ad9a89f414626)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, struct _jc_java_awt_Menu$object *);
	void	(*addMenu$c531b8aa16a72c05)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, struct _jc_object *);
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *);
	void	(*delMenu$26289899e46c5ca6)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, jint);
	void	(*nativeSetHelpMenu$5b3ac97d41e5de26)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, struct _jc_object *);
	void	(*setFont$d9ef91fc08961faa)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuBarPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuBarPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuBarPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkMenuBarPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkMenuBarPeer_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkMenuBarPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkMenuBarPeer

// class file dependencies
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class 73415100be020779 gnu_java_awt_peer_gtk_GtkMenuBarPeer
// @dep_class bf080bc730109d28 gnu_java_awt_peer_gtk_GtkMenuComponentPeer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkMenuComponentPeer

#include "gnu/java/awt/peer/gtk/GtkMenuComponentPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkMenuBarPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkMenuBarPeer_H_

// Forward structure declarations
struct _jc_java_awt_Menu$object;
struct _jc_java_awt_MenuBar$object;
struct _jc_java_awt_peer_MenuPeer$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method$_init$4781d7bab77689ff(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, struct _jc_java_awt_MenuBar$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method$addHelpMenu$817ad9a89f414626(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, struct _jc_java_awt_Menu$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method$addMenu$c531b8aa16a72c05(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method$delMenu$26289899e46c5ca6(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method$nativeSetHelpMenu$5b3ac97d41e5de26(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method$setFont$d9ef91fc08961faa(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method_info$addHelpMenu$817ad9a89f414626;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method_info$addMenu$c531b8aa16a72c05;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method_info$delMenu$26289899e46c5ca6;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method_info$nativeSetHelpMenu$5b3ac97d41e5de26;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$method_info$setFont$d9ef91fc08961faa;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vmethods {
	void	(*addHelpMenu$817ad9a89f414626)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, struct _jc_java_awt_Menu$object *) _JC_JCNI_ATTR;
	void	(*addMenu$c531b8aa16a72c05)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *) _JC_JCNI_ATTR;
	void	(*delMenu$26289899e46c5ca6)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, jint) _JC_JCNI_ATTR;
	void	(*nativeSetHelpMenu$5b3ac97d41e5de26)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setFont$d9ef91fc08961faa)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vmethods	gnu_java_awt_peer_gtk_GtkMenuBarPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuBarPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkMenuBarPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkMenuBarPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkMenuBarPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkMenuBarPeer_H_ */
